c       Last modified on August 22nd, 2002
c
c       Example of FORTRAN program using the functions and routines of
c       libCk.c. It uses an intermediate translation layer
c       'libFcompat.c' in order to convert between C and FORTRAN
c       argument passing conventions.
c
c       Details on the compilation are available in the makefile
c       provided in this package. It may not work with combinations of
c       compilers other than 'gcc' and 'g77' due to small differences in
c       the layout of the binary generated by different compilers.
c
c       Note that you should probably use DOUBLE PRECISION for all the
c       real variables, as the conversion between the C and FORTRAN
c       layers might break if the real numbers are not 2 words (64 bits)
c       wide.
c
c       Finally, note that you have to define two tables __STARTING at 0__ of
c       double precision real numbers, large enough to hold the number
c       of computed values of C(k) (i.e. the last argument of
c       f_create_ck_table(...)) + 3000. This is because the routine
c       f_create_ck_table(...) calculates 3000 extra values from the
c       asymptotic expansion of C(k). This is useful in order to check
c       the sum rule, which is sensitive to fairly large values of k.
c

	PROGRAM example
	IMPLICIT NONE
	DOUBLE PRECISION k
	DOUBLE PRECISION Qs
	DOUBLE PRECISION f_c_itp
	DOUBLE PRECISION avgkt
	DOUBLE PRECISION sumrule
	DOUBLE PRECISION k_min
	DOUBLE PRECISION k_max
	DOUBLE PRECISION t_k(0:10000)
	DOUBLE PRECISION t_C(0:10000)
	
	CALL set_fpu_state()

	CALL f_init_workspace(20)
	
c       Regarding the usage of this function, see the comment in the
c       file 'example.c' in the directory C/
c
c	CALL f_create_exponent_table(2000)

c       Create a table of values of k and C(k) for a given Qs
	Qs=25.D0
	CALL f_create_ck_table(Qs,t_k,t_C,avgkt,sumrule,k_min,k_max,2000)
 10	FORMAT ('#Qs:',f10.3,'  kmin:',f16.6,'  kmax:',f16.6,'  avg_kt:',f10.3,'  sum_rule:',f16.6)
	PRINT 10,Qs,k_min,k_max,avgkt,sumrule
	PRINT *,' '

c       Example of usage of the interpolating function: you give it your
c       value of k, the 2 tables, and their size (that's 2000+3000 for
c       this example) Note that arrays passed to a function are just a
c       pointer to the first element, so there is no way the function
c       can figure out the size if you don't tell it
	k=0.5D0
 20	PRINT *,k,f_c_itp(k,t_k,t_C,5000)
	k=k*1.02D0
	IF (k.LT.100000.D0) GOTO 20

	END
	

